*********
Tutorials
*********

Here are step-by-step guides that cover most of the functionalities and use cases.

.. warning::

    Note that this section is under construction. We intend to split over the contents
    from our first example for linear regression into the first few tutorial pages to
    walk you through the workflow and more advanced usages step by step.

    For the time being, we refer the audience to example gallery - 
    `polynomial linear regression <../cofi-examples/tools/sphinx_gallery/generated/linear_regression.html>`_ for
    guidance about using CoFI.


.. toctree::
    :caption: Basic usage
    :maxdepth: 1

    1_basic_example_optimizer
    2_basic_example_linear_lsq
    3_basic_example_sampler
    4_realworld_example
    5_another_realworld_example

.. toctree::
    :caption: Advanced usage
    :maxdepth: 1

    6_own_solver
